@@ -6,7 +6,7 @@
 #'
 #' The neutrosophic beta distribution with parameters \eqn{\alpha_N} and
 #' \eqn{\beta_N} has the probability density function
-#' \deqn{f_N(X) = \frac{1}{B(\alpha_N, \beta_N)} X^{\alpha_N - 1} (1 - X)^{\beta_N - 1}}
+#' \deqn{f_N(x) = \frac{1}{B(\alpha_N, \beta_N)} x^{\alpha_N - 1} (1 - x)^{\beta_N - 1}}
 #' for \eqn{\alpha_N \in (\alpha_L, \alpha_U)}, the first shape parameter which
 #' must be a positive interval, and \eqn{\beta_N \in (\beta_L, \beta_U)},
 #' the second shape parameter which must also be a positive interval, and
@@ -22,29 +22,34 @@
 #' @param shape1 the first shape parameter, which must be a positive interval.
 #' @param shape2 the second shape parameter, which must be a positive interval.
 #' @param lower.tail logical; if TRUE (default), probabilities are
-#' \eqn{P(X \ge x)}; otherwise, \eqn{P(X >x)}.
+#' \eqn{P(X \leq x)}; otherwise, \eqn{P(X >x)}.
 #'
 #' @return
-#' \code{pnsbeta} gives the distribution function,
-#' \code{dnsbeta} gives the density,
-#' \code{qnsbeta} gives the quantile function and
-#' \code{rnsbeta} generates random values from the neutrosophic Beta distribution.
+#' \code{dnsBeta} gives the density function
+#'
+#' \code{pnsBeta} gives the distribution function
+#'
+#' \code{qnsBeta} gives the quantile function
+#'
+#' \code{rnsBeta} generates random values from the neutrosophic Beta distribution.
 #'
 #' @references
 #'  Sherwani, R. Ah. K., Naeem, M., Aslam, M., Reza, M. A., Abid, M., Abbas, S. (2021).
 #'     Neutrosophic beta distribution with properties and applications.
 #'     \emph{Neutrosophic Sets and Systems}, 41, 209-214.
+#'
 #' @importFrom stats runif dbeta pbeta qbeta
+#'
 #' @examples
 #'
-#' dnsbeta(x = c(0.1, 0.2), shape1 = c(1, 1), shape2 = c(2, 2))
-#' dnsbeta(x = 0.1, shape1 = c(1, 1), shape2 = c(2, 2))
+#' dnsBeta(x = c(0.1, 0.2), shape1 = c(1, 1), shape2 = c(2, 2))
+#' dnsBeta(x = 0.1, shape1 = c(1, 1), shape2 = c(2, 2))
 #'
 #' x <- matrix(c(0.1, 0.1, 0.2, 0.3, 0.5, 0.5), ncol = 2, byrow = TRUE)
-#' dnsbeta(x, shape1 = c(1, 2), shape2 = c(2, 3))
+#' dnsBeta(x, shape1 = c(1, 2), shape2 = c(2, 3))
 #'
 #' @export
-dnsbeta <- function(x, shape1, shape2) {
+dnsBeta <- function(x, shape1, shape2) {
   if (any(shape1 <= 0) || any(shape2 <= 0) || any(x < 0)) {
     stop(message = "Arguments are incompatible.")
   }
@@ -72,11 +77,11 @@ dnsbeta <- function(x, shape1, shape2) {
 #' @name Neutrosophic Beta
 #' @examples
 #'
-#' pnsbeta(q = c(0.1, 0.1), shape1 = c(3, 1), shape2 = c(1, 3), lower.tail = FALSE)
-#' pnsbeta(x, shape1 = c(1, 2), shape2 = c(2, 2))
+#' pnsBeta(q = c(0.1, 0.1), shape1 = c(3, 1), shape2 = c(1, 3), lower.tail = FALSE)
+#' pnsBeta(x, shape1 = c(1, 2), shape2 = c(2, 2))
 #'
 #' @export
-pnsbeta <- function(q, shape1, shape2, lower.tail = TRUE) {
+pnsBeta <- function(q, shape1, shape2, lower.tail = TRUE) {
   if (any(shape1 <= 0) || any(shape2 <= 0) || any(q < 0)) {
     stop("Arguments are incompatible.")
   }
@@ -105,11 +110,11 @@ pnsbeta <- function(q, shape1, shape2, lower.tail = TRUE) {
 #' @name Neutrosophic Beta
 #' @examples
 #'
-#' qnsbeta(p = 0.1, shape1 = c(1, 1), shape2 = c(2, 2))
-#' qnsbeta(p = c(0.25, 0.5, 0.75), shape1 = c(1, 2), shape2 = c(2, 2))
+#' qnsBeta(p = 0.1, shape1 = c(1, 1), shape2 = c(2, 2))
+#' qnsBeta(p = c(0.25, 0.5, 0.75), shape1 = c(1, 2), shape2 = c(2, 2))
 #'
 #' @export
-qnsbeta <- function(p, shape1, shape2) {
+qnsBeta <- function(p, shape1, shape2) {
   if (any(p < 0) || any(p > 1)) {
     stop(message = "Warning: p should be in the interval [0,1].")
   }
@@ -137,16 +142,16 @@ qnsbeta <- function(p, shape1, shape2) {
 #' @name Neutrosophic Beta
 #' @examples
 #' # Simulate 10 numbers
-#' rnsbeta(n = 10, shape1 = c(1, 2), shape2 = c(1, 1))
+#' rnsBeta(n = 10, shape1 = c(1, 2), shape2 = c(1, 1))
 #' @export
-rnsbeta <- function(n, shape1, shape2) {
+rnsBeta <- function(n, shape1, shape2) {
   if (any(shape1 <= 0) || any(shape2 <= 0)) {
     stop(message = "Arguments are incompatible.")
   }
   shape1 <- rep(shape1, length.out = 2)
   shape2 <- rep(shape2, length.out = 2)
 
-  X <- qnsbeta(runif(n), shape1, shape2)
+  X <- qnsBeta(runif(n), shape1, shape2)
   condition <- X[, 1] > X[, 2]
   X[condition, 1:2] <- X[condition, 2:1]
 
