@@ -8,7 +8,7 @@
 #' has the density
 #' \deqn{f_X(x)=\bigg(\begin{array}{c}n \\ x\end{array}\bigg) p_N^{x}\left(1-p_N\right)^{n-x}}
 #' for \eqn{n \in \{1, 2, \ldots\}} and \eqn{p_N \in (p_L, p_U)} which must be \eqn{0<p_N<1}
-#' and \eqn{x \in \{0, 1, 2, \ldots\}}.
+#' and \eqn{x \in \{0, 1, 2, \ldots, n\}}.
 #'
 #' @name Neutrosophic Binomial
 #' @param x a vector or matrix of observations for which the pdf needs to be computed.
@@ -18,26 +18,33 @@
 #' @param size number of trials (zero or more), which must be a positive interval.
 #' @param prob probability of success on each trial, \eqn{0 \le prob \le 1}.
 #' @param lower.tail logical; if TRUE (default), probabilities are
-#' \eqn{P(X \ge x)}; otherwise, \eqn{P(X >x)}.
+#' \eqn{P(X \leq x)}; otherwise, \eqn{P(X >x)}.
 #'
 #' @return
-#'  \code{pnsbinom} gives the distribution function,
-#'  \code{dnsbinom} gives the density,
-#'  \code{qnsbinom} gives the quantile function and
-#'  \code{rnsbinom} generates random variables from the Binomial Distribution.
+#'  \code{dnsBinom} gives the probability mass function
+#'
+#'  \code{pnsBinom} gives the distribution function
+#'
+#'  \code{qnsBinom} gives the quantile function
+#'
+#'  \code{rnsBinom} generates random variables from the Binomial Distribution.
+#'
 #' @references
-#'        Granados, C. (2022). Some discrete neutrosophic distributions with
-#'         neutrosophic parameters based on neutrosophic random variables.
-#'         \emph{Hacettepe Journal of Mathematics and Statistics}, 51(5),
-#'         1442-1457.
+#' Granados, C. (2022). Some discrete neutrosophic distributions with
+#' neutrosophic parameters based on neutrosophic random variables.
+#' \emph{Hacettepe Journal of Mathematics and Statistics}, 51(5),
+#' 1442-1457.
+#'
 #' @importFrom stats runif dbinom pbinom qbinom
 #' @examples
 #' # Probability of X = 17 when X follows bin(n = 20, p = [0.9,0.8])
-#' dnsbinom(x = 17, size = 20, prob = c(0.9, 0.8))
+#' dnsBinom(x = 17, size = 20, prob = c(0.9, 0.8))
+#'
 #' x <- matrix(c(15, 15, 17, 18, 19, 19), ncol = 2, byrow = TRUE)
-#' dnsbinom(x = x, size = 20, prob = c(0.8, 0.9))
+#' dnsBinom(x = x, size = 20, prob = c(0.8, 0.9))
+#'
 #' @export
-dnsbinom <- function(x, size, prob) {
+dnsBinom <- function(x, size, prob) {
   if (any(size < 1) || any(prob <= 0) || any(prob > 1) || any(x < 0)) {
     stop(message = "Arguments are incompatible.")
   }
@@ -68,12 +75,12 @@ dnsbinom <- function(x, size, prob) {
 #' @name Neutrosophic Binomial
 #' @examples
 #'
-#' pnsbinom(q = 17, size = 20, prob = c(0.9, 0.8))
-#' pnsbinom(q = c(17, 18), size = 20, prob = c(0.9, 0.8))
-#' pnsbinom(q = x, size = 20, prob = c(0.9, 0.8))
+#' pnsBinom(q = 17, size = 20, prob = c(0.9, 0.8))
+#' pnsBinom(q = c(17, 18), size = 20, prob = c(0.9, 0.8))
+#' pnsBinom(q = x, size = 20, prob = c(0.9, 0.8))
 #' @export
 
-pnsbinom <- function(q, size, prob, lower.tail = TRUE) {
+pnsBinom <- function(q, size, prob, lower.tail = TRUE) {
   if (any(size < 1) || any(prob <= 0) || any(prob > 1) || any(q < 0)) {
     stop(message = "Arguments are incompatible.")
   }
@@ -105,11 +112,11 @@ pnsbinom <- function(q, size, prob, lower.tail = TRUE) {
 #' @name Neutrosophic Binomial
 #' @examples
 #'
-#' qnsbinom(p = 0.5, size = 20, prob = c(0.8, 0.9))
-#' qnsbinom(p = c(0.25, 0.5, 0.75), size = 20, prob = c(0.8, 0.9))
+#' qnsBinom(p = 0.5, size = 20, prob = c(0.8, 0.9))
+#' qnsBinom(p = c(0.25, 0.5, 0.75), size = 20, prob = c(0.8, 0.9))
 #'
 #' @export
-qnsbinom <- function(p, size, prob) {
+qnsBinom <- function(p, size, prob) {
   if (any(p < 0) || any(p > 1)) {
     stop(message = "Warning: p should be in the interval [0,1].")
   }
@@ -141,10 +148,10 @@ qnsbinom <- function(p, size, prob) {
 #' @examples
 #'
 #' # Simulate 10 numbers
-#' rnsbinom(n = 10, size = 20, prob = c(0.8, 0.9))
+#' rnsBinom(n = 10, size = 20, prob = c(0.8, 0.9))
 #'
 #' @export
-rnsbinom <- function(n, size, prob) {
+rnsBinom <- function(n, size, prob) {
   if (any(size < 1) || any(prob <= 0) || any(prob > 1)) {
     stop(message = "Arguments are incompatible.")
   }
@@ -152,7 +159,7 @@ rnsbinom <- function(n, size, prob) {
   size <- rep(size, length.out = 2)
   prob <- rep(prob, length.out = 2)
 
-  X <- qnsbinom(runif(n), size, prob)
+  X <- qnsBinom(runif(n), size, prob)
   condition <- X[, 1] > X[, 2]
   X[condition, 1:2] <- X[condition, 2:1]
 
