@@ -15,27 +15,35 @@
 #' @param q a vector or matrix of quantiles for which the cdf needs to be computed.
 #' @param p a vector or matrix of probabilities for which the quantile needs to be computed.
 #' @param n number of random values to be generated.
-#' @param prob probability of success on each trial, \eqn{0 < prob <= 1}.
+#' @param prob probability of success on each trial, \code{prob}\eqn{\in (0,1)}.
 #' @param lower.tail logical; if TRUE (default), probabilities are
-#' \eqn{P(X \ge x)}; otherwise, \eqn{P(X >x)}.
+#' \eqn{P(X \leq x)}; otherwise, \eqn{P(X >x)}.
 #'
 #' @return
-#'  \code{pnsgeom} gives the distribution function,
-#'  \code{dnsgeom} gives the density,
-#'  \code{qnsgeom} gives the quantile function and
-#'  \code{rnsgeom} generates random variables from the Geometric Distribution.
+#'  \code{dnsGeom} gives the probability mass function
+#'
+#'  \code{pnsGeom} gives the distribution function
+#'
+#'  \code{qnsGeom} gives the quantile function
+#'
+#'  \code{rnsGeom} generates random variables from the Geometric Distribution.
+#'
 #' @references
-#'        Granados, C. (2022).
-#'        Some discrete neutrosophic distributions with neutrosophic parameters based on neutrosophic random variables.
-#'         \emph{Hacettepe Journal of Mathematics and Statistics}, 51(5), 1442-1457.
+#' Granados, C. (2022). Some discrete neutrosophic distributions with
+#' neutrosophic parameters based on neutrosophic random variables.
+#' \emph{Hacettepe Journal of Mathematics and Statistics}, 51(5), 1442-1457.
+#'
 #' @importFrom stats runif dgeom pgeom qgeom
+#'
 #' @examples
 #' # One person participates each week with a ticket in a lottery game, where
 #' # the probability of winning the first prize is (10^(-8), 10^(-6)).
 #' # Probability of one persons wins at the fifth year?
-#' dnsgeom(x = 5, prob = c(1e-8, 1e-6))
+#'
+#' dnsGeom(x = 5, prob = c(1e-8, 1e-6))
+#'
 #' @export
-dnsgeom <- function(x, prob) {
+dnsGeom <- function(x, prob) {
   if (any(prob <= 0) || any(prob > 1) || any(x < 0)) {
     stop(message = "Arguments are incompatible.")
   }
@@ -54,22 +62,20 @@ dnsgeom <- function(x, prob) {
     stop(message = "Arguments are incompatible.")
   }
 
-
   pdf <- matrix(NA, nrow = nrow(x), ncol = 2)
   for (i in 1:2) {
     pdf[, i] <- stats::dgeom(x[, i], prob = prob[i])
   }
 
-
   return(pdf)
 }
 #' @name Neutrosophic Geometric
 #' @examples
 #' # Probability of one persons wins after 10 years?
-#' pnsgeom(q = 10, prob = c(1e-8, 1e-6))
-#' pnsgeom(q = 10, prob = c(1e-8, 1e-6), lower.tail = FALSE)
+#' pnsGeom(q = 10, prob = c(1e-8, 1e-6))
+#' pnsGeom(q = 10, prob = c(1e-8, 1e-6), lower.tail = FALSE)
 #' @export
-pnsgeom <- function(q, prob, lower.tail = TRUE) {
+pnsGeom <- function(q, prob, lower.tail = TRUE) {
   if (any(prob <= 0) || any(prob > 1) || any(q < 0)) {
     stop(message = "Arguments are incompatible.")
   }
@@ -99,9 +105,9 @@ pnsgeom <- function(q, prob, lower.tail = TRUE) {
 #' @name Neutrosophic Geometric
 #' @examples
 #' # Calculate the quantiles
-#' qnsgeom(p = c(0.25, 0.5, 0.75), prob = c(1e-8, 1e-6))
+#' qnsGeom(p = c(0.25, 0.5, 0.75), prob = c(1e-8, 1e-6))
 #' @export
-qnsgeom <- function(p, prob) {
+qnsGeom <- function(p, prob) {
   if (any(p < 0) || any(p > 1)) {
     stop(message = "Warning: p should be in the interval [0,1].")
   }
@@ -129,16 +135,16 @@ qnsgeom <- function(p, prob) {
 #' @name Neutrosophic Geometric
 #' @examples
 #' # Simulate 10 numbers
-#' rnsgeom(n = 10, prob = c(1e-8, 1e-6))
+#' rnsGeom(n = 10, prob = c(1e-8, 1e-6))
 #' @export
-rnsgeom <- function(n, prob) {
+rnsGeom <- function(n, prob) {
   if (any(prob <= 0) || any(prob > 1)) {
     stop(message = "Arguments are incompatible.")
   }
 
   prob <- rep(prob, length.out = 2)
 
-  X <- qnsgeom(runif(n), prob)
+  X <- qnsGeom(runif(n), prob)
   condition <- X[, 1] > X[, 2]
   X[condition, 1:2] <- X[condition, 2:1]
 
