@@ -17,13 +17,17 @@
 #' @param n number of random values to be generated.
 #' @param lambda the mean, which must be a positive interval.
 #' @param lower.tail logical; if TRUE (default), probabilities are
-#' \eqn{P(X \ge x)}; otherwise, \eqn{P(X >x)}.
+#' \eqn{P(X \leq x)}; otherwise, \eqn{P(X >x)}.
 #'
 #' @return
-#'  \code{pnspois} gives the distribution function,
-#'  \code{dnspois} gives the density,
-#'  \code{qnspois} gives the quantile function and
-#'  \code{rnspois} generates random variables from the neutrosophic Poisson Distribution.
+#'
+#'  \code{dnsPois} gives the probability mass function
+#'
+#'  \code{pnsPois} gives the distribution function
+#'
+#'  \code{qnsPois} gives the quantile function
+#'
+#'  \code{rnsPois} generates random variables from the neutrosophic Poisson Distribution.
 #' @references
 #'        Alhabib, R., Ranna, M. M., Farah, H., Salama, A. A. (2018).
 #'        Some neutrosophic probability distributions.
@@ -33,12 +37,12 @@
 #' # In a company, Phone employee receives phone calls, the calls arrive with
 #' # rate of [1 , 3] calls per minute, we will calculate
 #' # the probability that the employee will not receive any call within a minute
-#' dnspois(x = 0, lambda = c(1, 3))
+#' dnsPois(x = 0, lambda = c(1, 3))
 #'
 #' # the probability that employee would not receive any call within 5 minutes
-#' dnspois(x = 0, lambda = c(5, 15))
+#' dnsPois(x = 0, lambda = c(5, 15))
 #' @export
-dnspois <- function(x, lambda) {
+dnsPois <- function(x, lambda) {
   if (any(lambda < 0)) {
     stop(message = "Arguments are incompatible.")
   }
@@ -68,11 +72,11 @@ dnspois <- function(x, lambda) {
 #' @name Neutrosophic Poisson
 #' @examples
 #' # the probability that the employee will receive at least one call within a minute
-#' pnspois(q = 1, lambda = c(1, 3), lower.tail = FALSE)
+#' pnsPois(q = 1, lambda = c(1, 3), lower.tail = FALSE)
 #' # the probability that the employee will receive at most three calls within 5 minutes
-#' pnspois(q = 3, lambda = c(5, 15), lower.tail = TRUE)
+#' pnsPois(q = 3, lambda = c(5, 15), lower.tail = TRUE)
 #' @export
-pnspois <- function(q, lambda, lower.tail = TRUE) {
+pnsPois <- function(q, lambda, lower.tail = TRUE) {
   if (any(lambda < 0)) {
     stop("Arguments are incompatible.")
   }
@@ -106,9 +110,9 @@ pnspois <- function(q, lambda, lower.tail = TRUE) {
 #' @name Neutrosophic Poisson
 #' @examples
 #' # Calcaute the quantiles
-#' qnspois(p = c(0.25, 0.5, 0.75), lambda = c(1, 3))
+#' qnsPois(p = c(0.25, 0.5, 0.75), lambda = c(1, 3))
 #' @export
-qnspois <- function(p, lambda) {
+qnsPois <- function(p, lambda) {
   if (any(p < 0) || any(p > 1)) {
     stop(message = "Warning: p should be in the interval [0,1].")
   }
@@ -138,16 +142,16 @@ qnspois <- function(p, lambda) {
 #' @name Neutrosophic Poisson
 #' @examples
 #' # Simulate 10 values
-#' rnspois(n = 10, lambda = 1)
+#' rnsPois(n = 10, lambda = 1)
 #' @export
-rnspois <- function(n, lambda) {
+rnsPois <- function(n, lambda) {
   if (any(lambda < 0)) {
     stop(message = "Arguments are incompatible.")
   }
 
   lambda <- rep(lambda, length.out = 2)
 
-  X <- qnspois(runif(n), lambda)
+  X <- qnsPois(runif(n), lambda)
   condition <- X[, 1] > X[, 2]
   X[condition, 1:2] <- X[condition, 2:1]
 
