@@ -5,7 +5,7 @@
 #' variable \eqn{X} with parameters \eqn{a_N} and  \eqn{b_N}.
 #'
 #' The neutrosophic Uniform distribution with parameters
-#' \eqn{\max_N} and \eqn{\min_N} has the density
+#' \eqn{a_N} and \eqn{b_N} has the density
 #' \deqn{f_N(x)=\frac{1}{b_N-a_N}}
 #' for \eqn{a_N \in (a_L, a_U)}  lower parameter interval, \eqn{b_N \in (b_L,b_U)},
 #'  upper parameter interval.
@@ -18,33 +18,37 @@
 #' @param min lower limits of the distribution. Must be finite.
 #' @param max upper limits of the distribution. Must be finite.
 #' @param lower.tail logical; if TRUE (default), probabilities are
-#' \eqn{P(X \ge x)}; otherwise, \eqn{P(X >x)}.
+#' \eqn{P(X \leq x)}; otherwise, \eqn{P(X >x)}.
 #'
 #' @return
-#'  \code{pnsunif} gives the distribution function,
-#'  \code{dnsunif} gives the density,
-#'  \code{qnsunif} gives the quantile function and
-#'  \code{rnsunif} generates random variables from the neutrosophic Uniform Distribution.
+#'  \code{dnsUnif} gives the density function
+#'
+#'  \code{pnsUnif} gives the distribution function
+#'
+#'  \code{qnsUnif} gives the quantile function
+#'
+#'  \code{rnsUnif} generates random variables from the neutrosophic Uniform Distribution.
+#'
 #' @references
-#'    Alhabib, R., Ranna, M. M., Farah, H., & Salama, A. A. (2018).
-#'     Some neutrosophic probability distributions.
-#'     \emph{Neutrosophic Sets and Systems}, 22, 30-38.
+#' Alhabib, R., Ranna, M. M., Farah, H., & Salama, A. A. (2018). Some neutrosophic
+#' probability distributions, \emph{Neutrosophic Sets and Systems}, 22, 30-38.
 #'
 #' @importFrom stats runif dunif punif qunif
+#'
 #' @examples
 #'
-#' dnsunif(x = 1, min = c(0, 5), max = c(15, 20))
-#' dnsunif(x = c(6, 10), min = c(0, 5), max = c(15, 20))
+#' dnsUnif(x = 1, min = c(0, 5), max = c(15, 20))
+#' dnsUnif(x = c(6, 10), min = c(0, 5), max = c(15, 20))
 #'
 #' punif(q = 1, min = c(0, 5), max = c(15, 20))
 #' punif(q = c(6, 10), min = c(0, 5), max = c(15, 20))
 #'
-#' qnsunif(p = c(0.25, 0.5, 0.75), min = c(0, 5), max = c(15, 20))
+#' qnsUnif(p = c(0.25, 0.5, 0.75), min = c(0, 5), max = c(15, 20))
 #'
-#' rnsunif(n = 10, min = c(0, 5), max = c(15, 20))
+#' rnsUnif(n = 10, min = c(0, 5), max = c(15, 20))
 #'
 #' @export
-dnsunif <- function(x, min, max) {
+dnsUnif <- function(x, min, max) {
   if (any(max <= min)) {
     stop(message = "Arguments are incompatible.")
   }
@@ -64,13 +68,11 @@ dnsunif <- function(x, min, max) {
     pdf[, i] <- stats::dunif(x[, i], min = min[i], max = max[i])
   }
 
-
-
   return(pdf)
 }
 #' @name Neutrosophic Uniform
 #' @export
-pnsunif <- function(q, min, max, lower.tail = TRUE) {
+pnsUnif <- function(q, min, max, lower.tail = TRUE) {
   if (any(max <= min)) {
     stop(message = "Arguments are incompatible.")
   }
@@ -90,8 +92,6 @@ pnsunif <- function(q, min, max, lower.tail = TRUE) {
     cdf[, i] <- stats::punif(q[, i], min = min[i], max = max[i])
   }
 
-
-
   if (!lower.tail) {
     cdf <- 1 - cdf
   }
@@ -101,7 +101,7 @@ pnsunif <- function(q, min, max, lower.tail = TRUE) {
 }
 #' @name Neutrosophic Uniform
 #' @export
-qnsunif <- function(p, min, max) {
+qnsUnif <- function(p, min, max) {
   if (any(max <= min)) {
     stop(message = "Arguments are incompatible.")
   }
@@ -126,14 +126,14 @@ qnsunif <- function(p, min, max) {
 }
 #' @name Neutrosophic Uniform
 #' @export
-rnsunif <- function(n, min, max) {
+rnsUnif <- function(n, min, max) {
   if (any(max <= min)) {
     stop(message = "Arguments are incompatible.")
   }
   max <- rep(max, length.out = 2)
   min <- rep(min, length.out = 2)
 
-  X <- qnsunif(runif(n), min, max)
+  X <- qnsUnif(runif(n), min, max)
   condition <- X[, 1] > X[, 2]
   X[condition, 1:2] <- X[condition, 2:1]
 
